Expression Serializer Extension — SQLAlchemy 1.4 Documentation

Release: 1.4.48 | Release Date: April 30, 2023

# SQLAlchemy 1.4 Documentation

# Expression Serializer Extension

Serializer/Deserializer objects for usage with SQLAlchemy query structures, allowing “contextual” deserialization.

Any SQLAlchemy query structure, either based on sqlalchemy.sql.* or sqlalchemy.orm.* can be used. The mappers, Tables, Columns, Session etc. which are referenced by the structure are not persisted in serialized form, but are instead re-associated with the query structure when it is deserialized.

Warning

The serializer extension uses pickle to serialize and deserialize objects, so the same security consideration mentioned in the python documentation apply.

Usage is nearly the same as that of the standard Python pickle module:

    from sqlalchemy.ext.serializer import loads, dumps
    metadata = MetaData(bind=some_engine)
    Session = scoped_session(sessionmaker())

    # ... define mappers

    query = Session.query(MyClass).
        filter(MyClass.somedata=='foo').order_by(MyClass.sortkey)

    # pickle the query
    serialized = dumps(query)

    # unpickle.  Pass in metadata + scoped_session
    query2 = loads(serialized, metadata, Session)

    print query2.all()

Similar restrictions as when using raw pickle apply; mapped classes must be themselves be pickleable, meaning they are importable from a module-level namespace.

The serializer module is only appropriate for query structures. It is not needed for:

- instances of user-defined classes. These contain no references to engines, sessions or expression constructs in the typical case and can be serialized directly.

- Table metadata that is to be loaded entirely from the serialized structure (i.e. is not already declared in the application). Regular pickle.loads()/dumps() can be used to fully dump any `MetaData` object, typically one which was reflected from an existing database at some previous point in time. The serializer module is specifically for the opposite case, where the Table metadata is already present in memory.

Object Name | Description
--- | ---
Deserializer(file[, metadata, scoped_session, engine]) |
dumps(obj[, protocol]) |
loads(data[, metadata, scoped_session, engine]) |
Serializer(*args, **kw) |

function sqlalchemy.ext.serializer.Deserializer(file, metadata=None, scoped_session=None, engine=None)

function sqlalchemy.ext.serializer.Serializer(*args, **kw)

function sqlalchemy.ext.serializer.dumps(obj, protocol=5)

function sqlalchemy.ext.serializer.loads(data, metadata=None, scoped_session=None, engine=None)